@@ -1,5 +1,5 @@
 package TAP::Parser::Iterator::PherkinStream;
-$TAP::Parser::Iterator::PherkinStream::VERSION = '0.57';
+$TAP::Parser::Iterator::PherkinStream::VERSION = '0.58';
 use strict;
 use warnings;
 
@@ -7,9 +7,10 @@ use base 'TAP::Parser::Iterator::Stream';
 
 
 sub _initialize {
-    my ($self, $fh, $pherkin) = @_;
+    my ($self, $fh, $pherkin, $child_pid) = @_;
 
     $self->{pherkin} = $pherkin;
+    $self->{child_pid} = $child_pid;
     return $self->SUPER::_initialize($fh);
 }
 
@@ -17,6 +18,9 @@ sub _finish {
     my $self = shift;
 
     $self->{pherkin}->_post_run();
+    if ($self->{child_pid}) {
+        waitpid $self->{child_pid}, 0; # reap child process
+    }
     return $self->SUPER::_finish(@_);
 }
 
